﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Browser;
using System.Windows.Media.Imaging;

namespace SearchBook
{
    public partial class Page : UserControl
    {
        //webService
        WebService.Service1SoapClient ws = new SearchBook.WebService.Service1SoapClient();

        //for doubleclick
        bool singleClick = false;
        System.Windows.Threading.DispatcherTimer timer;


        
        ObservableCollection<SearchBook.WebService.Book> bookcollection = new ObservableCollection<SearchBook.WebService.Book>();
        ObservableCollection<SearchBook.WebService.Blog> blogcollection = new ObservableCollection<SearchBook.WebService.Blog>();
        ObservableCollection<SearchBook.WebService.WebPage> webpagecollection = new ObservableCollection<SearchBook.WebService.WebPage>();

        public Page()
        {
            InitializeComponent();
            //HtmlPage.Window.Navigate(new Uri("http://www.naver.com"));

        

            Visibility = Visibility.Collapsed;
            //for doubleclick
            timer = new System.Windows.Threading.DispatcherTimer();
            timer.Interval = TimeSpan.FromMilliseconds(500);
            timer.Tick += new EventHandler(timer_Tick);

            //button event
            btnSearch.Click += new RoutedEventHandler(btnSearch_Click);
            btnClose.Click += new RoutedEventHandler(btnClose_Click);
            
        }

        void btnClose_Click(object sender, RoutedEventArgs e)
        {
            Visibility = Visibility.Collapsed;            
        }

        
        void timer_Tick(object sender, EventArgs e)
        {
            timer.Stop();
            singleClick = false; // expires
        }

        private void Grid_Loaded(object sender, RoutedEventArgs e)
        {
            FrameworkElement g = sender as FrameworkElement;
            g.Width = bookList.ActualWidth;
        }

        private void Grid_Book_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            if (!singleClick)
            {
                timer.Start();
                singleClick = true;
            }
            else
            {
                //HtmlPage.Window.Alert(bookList.SelectedIndex.ToString()); //index는 번호
                //HtmlPage.Window.Alert(bookList.SelectedItem.ToString()); //item은 안에있는 값을 보내준다.                
                //tbLink.Text = bookList.SelectedIndex.ToString();                
                //insert data in bookViewer                
                bookViewer.tbViewerTitle.Text = bookcollection[bookList.SelectedIndex].title.ToString();
                bookViewer.imgViewerImage.Source = new BitmapImage(new Uri(bookcollection[bookList.SelectedIndex].image.ToString(), UriKind.Absolute));
                bookViewer.HiddenImageUrl.Text = bookcollection[bookList.SelectedIndex].image.ToString(); //url을 보내주기위해 숨겨서 보낼것
                bookViewer.tbViewerDescription.Text = bookcollection[bookList.SelectedIndex].description.ToString();
                bookViewer.tbPrice.Text = "가격 : " + bookcollection[bookList.SelectedIndex].price.ToString();
                bookViewer.tbDisCount.Text = "할인된가격 : "+ bookcollection[bookList.SelectedIndex].discount.ToString();
                bookViewer.tbAuthor.Text = "저자 : " + bookcollection[bookList.SelectedIndex].author.ToString();
                bookViewer.btnHyperLink.NavigateUri = (new Uri(bookcollection[bookList.SelectedIndex].link.ToString()));
                bookViewer.Visibility = Visibility.Visible;                
                bookViewer.Storyboard1.Begin();            
            }
        }


        private void Grid_Blug_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            if (!singleClick)
            {
                timer.Start();
                singleClick = true;
            }
            else
            {
                HtmlPage.Window.Navigate(new Uri(blogcollection[blogList.SelectedIndex].link.ToString()),"_blank");
                
            }
        }

        private void Grid_WebPage_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            if (!singleClick)
            {
                timer.Start();
                singleClick = true;
            }
            else
            {
                HtmlPage.Window.Navigate(new Uri(webpagecollection[WebPageList.SelectedIndex].link.ToString()),"_blank");

            }
        }



        private void theList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            singleClick = false;
        }



        void btnSearch_Click(object sender, RoutedEventArgs e)
        {      
            string query = txtbox.Text;
            //bookAPI load
            ws.BookApiCompleted += new EventHandler<SearchBook.WebService.BookApiCompletedEventArgs>(ws_BookApiCompleted);
            ws.BookApiAsync(query);

            //blogAPI load
            ws.BlogApiCompleted += new EventHandler<SearchBook.WebService.BlogApiCompletedEventArgs>(ws_BlogApiCompleted);
            ws.BlogApiAsync(query);

            //WebPageAPI load
            ws.WebPageAPICompleted += new EventHandler<SearchBook.WebService.WebPageAPICompletedEventArgs>(ws_WebPageAPICompleted);
            ws.WebPageAPIAsync(query);
            

        }

        void ws_WebPageAPICompleted(object sender, SearchBook.WebService.WebPageAPICompletedEventArgs e)
        {
            webpagecollection = e.Result;
            WebPageList.ItemsSource = webpagecollection;
            //WebPageList.Items.Add("hi");
         
        }

        void ws_BlogApiCompleted(object sender, SearchBook.WebService.BlogApiCompletedEventArgs e)
        {
            blogcollection = e.Result;
            blogList.ItemsSource = blogcollection;
            
            
        }       
    

        void  ws_BookApiCompleted(object sender, SearchBook.WebService.BookApiCompletedEventArgs e)
        {      
            //var bookdata = e.Result;
            bookcollection = e.Result;
            

            
            //웹서비스쪽에서 string말로 image로 정의 할것(근데 이거는 찾아야함)
            //bookcollection[0].image = new BitmapImage(new Uri(bookcollection[0].image.ToString(), UriKind.Absolute)); 
            for (int i = 0; i < bookcollection.Count; i++)
            {
                bookcollection[i].image_bitmap = new BitmapImage(new Uri(bookcollection[i].image.ToString(), UriKind.Absolute));
            }
            //MessageBox.Show(bookcollection[0].image_bitmap.ToString());           
            bookList.ItemsSource = bookcollection;
            

            //bookViewer.DataContext = e.Result;        
            //bookdata[0].title.ToString();

            //temp확인하기 위해서            
            /*
            foreach (var strText in bookdata)
            {
                string link = strText.link;
                booklink.Add(strText.link);
               
            }
            */
            
        }        

    }
}
